# PySachi - Python static code analysis for Entropy

[![Build Status](https://travis-ci.org/Nauja/pysachi.png?branch=master)](https://travis-ci.org/Nauja/pysachi)
[![Test Coverage](https://codeclimate.com/github/Nauja/pyrabbit/badges/coverage.svg)](https://codeclimate.com/github/Nauja/pyrabbit/coverage)
[![Code Climate](https://codeclimate.com/github/Nauja/pyrabbit/badges/gpa.svg)](https://codeclimate.com/github/Nauja/pyrabbit)
[![Docs](https://readthedocs.org/projects/pysachi/badge/?style=flat)](https://pysachi.readthedocs.io/en/latest/)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/Nauja/pysachi/issues)

## Introduction

**I strongly believe that rabbits are keepers of the entropy.**

PySachi is a Python static code analysis tool to check your code against the [Entropy](https://github.com/Nauja/Entropy) coding standard, measuring entropy and displaying warnings.
